@@ -16,13 +16,12 @@ class XDocument(Document):
     # Date modified
     date_modified = DateTimeField(default=datetime.utcnow)
 
-
     @classmethod
     def reference_frame(cls, products=None) -> pd.DataFrame:
         products = products or cls.objects
 
         frame = pd.DataFrame(
-            {product.name: pd.Series({key: data for key, data in product.reference.items()}) for product in
+            {product.name: pd.Series({key: data for key, data in product.reference.items()}, dtype=object) for product in
              products}).transpose()
         frame.index.name = cls.__name__.lower()
         return frame.sort_index()
@@ -36,9 +35,9 @@ class XDocument(Document):
             return cls.objects(name__in=names)
 
     @classmethod
-    def to_dict(cls):
+    def to_dict(cls, names=None):
         # represent all documents of a class as a dictionary
-        return {x.name: x for x in cls.objects}
+        return {x.name: x for x in cls.products(names=names)}
 
     @classmethod
     def apply(cls, f, default, products=None) -> pd.DataFrame:
@@ -47,9 +46,14 @@ class XDocument(Document):
         for product in products:
             try:
                 yield product.name, f(product)
-            except:
+            except (AttributeError, KeyError):
                 yield product.name, default
 
+    @classmethod
+    def frame(cls, series, products=None) -> pd.DataFrame:
+        products = products or cls.objects
+        return pd.DataFrame({p.name: p.__getattribute__(series) for p in products}).dropna(axis=1, how="all")
+
     def __lt__(self, other):
         # sort documents by name
         return self.name < other.name
@@ -63,4 +67,7 @@ class XDocument(Document):
         return hash(self.to_json())
 
     def __str__(self):
+        return "<{type}: {name}>".format(type=self.__class__.__name__, name=self.name)
+
+    def __repr__(self):
         return "<{type}: {name}>".format(type=self.__class__.__name__, name=self.name)
\ No newline at end of file
